#!/bin/ksh
# @(#) Copyright 2000-2005 Vallent Corp. All rights reserved.
# @(#) loader.sh 1.4.0
# @(#) 

############################################################################
# NB!!!!
# Because we're usually run via the sentry, it's important not to resource
# the .prospectrc file, as some variables may have been redefined from
# arguments passed to the sentry startup script sentry.sh.
############################################################################

# We need to augment the loader's argument list with the data-gateway we use
#WRITETOFILE=-wtf

while [ $# -gt 0 ]
do
case $1 in
    -filename)
	    shift

	    if ! test -s $1
	    then
	      echo "ERROR: $FILENAME not valid file size"
	      echo "Reason: $FILENAME must be greater than 0 size."
	      exit 1
	    fi

	    FULLNAME=$1
	    DIRNAME=`dirname $1`
	    FILENAME=`basename $1`
	    FILEMAIN=${FILENAME%.*}
	    FILEEXT=${FILENAME##*.}

            TOKENS=`echo $FILENAME | tr '.' ' '`
            NUM_TOKENS=`echo $TOKENS | wc -w`

            if [ $NUM_TOKENS -lt 4 ]
            then
              echo "Error: $FILENAME not valid Motorola BSC_BGF PM Data File name."
              echo "Reason: $FILENAME should have 4 or more fields."
              exit 1
            fi

            MSCNAME=`echo $TOKENS | cut -d ' ' -f1`
	    TMSTAMP=`echo $TOKENS | cut -d ' ' -f3`
	    DATE=`echo $TMSTAMP | cut -c1-8`
	    MONTH=`echo $TMSTAMP | cut -c5-6`
	    DAY=`echo $TMSTAMP | cut -c7-8`
	    YEAR=`echo $TMSTAMP | cut -c1-4`
	    HOUR=`echo $TMSTAMP | cut -c9-10`
	    MINUTES=`echo $TMSTAMP | cut -c11-12`
	    BSCID=`echo $TOKENS | cut -d ' ' -f2`

            NELINE=`awk '$1=="'$MSCNAME'" {print $2,$3,$4,$5,$6,$7}' $PROSPECT_HOME/ne_list`
            SYSTEM_ID=`echo $NELINE | cut -d ' ' -f1`
            NE_ID=`echo $NELINE | cut -d ' ' -f2`
            REV=`echo $NELINE | cut -d ' ' -f3`
            PREFIX=`echo $NELINE | cut -d ' ' -f4`
            NE_SYSTEM=`echo $NELINE | cut -d ' ' -f5`
            NE_TYPE=`echo $NELINE | cut -d ' ' -f6`

	    OMCR_STRING=`echo ${OMCRID} | tr -d [0-9]`
		if [ ! -z "$OMCR_STRING" ]
		then
			echo "Error: $FILENAME not valid Motorola OMCR_PMC171 PM data File name."
			echo "Reason: OMCR_ID should be numeric"
			exit 1
		fi
	    MM_STRING=`echo $BSCID | tr -d [0-9]`
		if [ ! -z "$MM_STRING" ]
		then
			echo "Error: $FILENAME not valid Motorola OMCR_PMC171 PM data File name."
			echo "Reason: MM_ID should be numeric"
			exit 1
		fi

#            if [[ $MINUTES != "00" &&  $MINUTES != "30" ]]
#	    then
#	       echo "Error: $TMSTAMP not valid Motorola OMCR_PMC171 PM Data File Time"
#	       echo "Reason: $TMSTAMP should be an hour or half hour type"
#	       exit 1
#
#            fi 
#
           if [[ $MINUTES != "00" && $MINUTES != "10" &&$MINUTES != "20" && $MINUTES != "30" && $MINUTES != "40" && $MINUTES != "50" ]]
            then
               echo "Error: $TMSTAMP not valid Motorola PMC171 Data File Time"
               echo "Reason: $TMSTAMP should be on the 10 min mark"
               exit 1

            fi
	    
	    INTERVAL=30
	    FILENAME=`echo "$FILENAME" | sed 's/\.gz$//'`

	    NELIST_TMP="NE_LIST|$FILENAME|$MSCNAME|$SYSTEM_ID|$NE_ID|$REV|$PREFIX|$NE_SYSTEM|$NE_TYPE"
            echo "${NELIST_TMP}" > ne_list_tmp.$$	    

	    KEY_PREFIX=`echo $SYSTEM_ID-$MSC_ID-$BSCID`
	    KEY_TSTAMP=`echo $MONTH/$DAY/$YEAR $HOUR:$MINUTES`
	    echo "START_TAB|${KEY_PREFIX}|${KEY_TSTAMP}|${KEY_TSTAMP}|${INTERVAL}" > key_prefix.$$

	    FILETMSTAMP1="FILETMSTAMP|$FILENAME|ne_name|$MSCNAME"
	    FILETMSTAMP2="FILETMSTAMP|$FILENAME|timestamp|$TMSTAMP"
	    FILETMSTAMP3="FILETMSTAMP|$FILENAME|omcr_num|$OMCRID"
	    FILETMSTAMP4="FILETMSTAMP|$FILENAME|bsc_id|$BSCID"

            echo "${FILETMSTAMP1}" > headerfile.$$
            echo "${FILETMSTAMP2}" >> headerfile.$$
            echo "${FILETMSTAMP3}" >> headerfile.$$
            echo "${FILETMSTAMP4}" >> headerfile.$$

	    ;;

    -tableLoadId)
            shift
	    case $1 in
                TLID_OMCR_PMC171)
		    DG_FILE=$PROSPECT_HOME/MotoCDMA_loader/OMCR_PMC171/GATEWAY/dataGateway.hdd
		;;
		*)
		    echo "$0: Unknown -tableLoadId $1"
		    exit 1
		    ;;
	    esac
	    ARGS="$ARGS -tableLoadId $1 -dg $DG_FILE"
        ;;
# Ignore the -dg parameters and skip it's contents
    -dg)
	    shift
	;;
    *) 
        ARGS="$ARGS $1"
        ;;

esac
shift
done
echo "ARGS ARE: $ARGS"

# Invoke the loader
${PROSPECT_HOME}/scripts/decompress $FULLNAME | cat ne_list_tmp.$$ - | cat headerfile.$$ - | cat key_prefix.$$ - | \
    ${LOADERPROGRAM} ${CONFIGSET} ${WMPM} -pipeFile $FULLNAME ${ARGS} \
    ${SILENTPARSE} ${WRITETOFILE} -suppress PKN -suppress DPK

EXIT_CODE=$?

rm -f ne_list_tmp.$$
rm -f headerfile.$$
rm -f key_prefix.$$

exit $EXIT_CODE
